@@ -3,7 +3,7 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import cartopy.crs as ccrs
 import cartopy.feature as cfeature
-from cartopy.io.img_tiles import StamenTerrain, GoogleTiles, OSM
+from cartopy.io.img_tiles import Stamen, GoogleTiles, OSM
 import cartopy.io.shapereader as shpreader
 from matplotlib.transforms import offset_copy
 
@@ -173,7 +173,7 @@ class StaticMap:
         #
         # select projection
         if self.projection == "MercatorStamen":
-            tiler = StamenTerrain(**kwargs)
+            tiler = Stamen(**kwargs)
             this_proj = tiler.crs
         #
         # Google kwargs: style='street','satellite', 'terrain' or 'only_streets'
@@ -192,12 +192,13 @@ class StaticMap:
         #
         # create world's self.axes in desired position inside fig if specified
         if self.position is not None:
-            self.ax = plt.axes(position, projection = this_proj)
+            self.ax = plt.axes(position, projection = this_proj, frameon = False)
         else:
-            self.ax = plt.axes(projection = this_proj)
+            self.ax = plt.axes(projection = this_proj, frameon = False)
         #
-        # don't plot frame
-        self.ax.outline_patch.set_visible(False)
+        # don't plot frame 
+        # NOTE: Deprecated on cartopy 0.21, changed to frameon=False on plt.axes
+        # self.ax.outline_patch.set_visible(False)
         #
         # the view window
         coords_d = {"EC": [-80, -75, 33.5, 36.55],
