@@ -1,5 +1,8 @@
 '''Test WebMap layers'''
 import oneworld as ow
+import os
+
+cwd = os.path.dirname(os.path.realpath(__file__))
 
 def test_wm_lay():
     mymap = ow.WebMap(center = [39,-96.8], zoom = 4)
@@ -10,10 +13,10 @@ def test_wm_lay():
     mymap.add_basemap(name = 'Farms')
 
     df = ow.load_dataset('farms')
-    mymap.add_choropleth(json_file = 'tests_data/us_states.json',
+    mymap.add_choropleth(json_file = cwd+'/us_states.json',
                          geoid = 'FIPS', color = 'Region', data = df,
                          json_key = 'GEOID', layer = 'Regions')
-    mymap.add_choropleth(json_file = 'tests_data/us_states.json',
+    mymap.add_choropleth(json_file = cwd+'/us_states.json',
                          geoid = 'FIPS', color = 'Number of farms', data = df,
                          json_key = 'GEOID', palette = 'YlGn', layer = 'Farms')
 
